Documentation
¶
Overview ¶
Copyright (c) 2017-2018 Uber Technologies, Inc.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright (c) 2017-2018 Uber Technologies, Inc.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright (c) 2017-2018 Uber Technologies, Inc.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright (c) 2017-2018 Uber Technologies, Inc.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright (c) 2017-2018 Uber Technologies, Inc.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright (c) 2017-2018 Uber Technologies, Inc.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Index ¶
- func NewEnumMutator(store kv.TxnStore, schemaMutator common.TableSchemaMutator) common.EnumMutator
- func NewIngestionAssignmentMutator(etcdStore kv.TxnStore) common.IngestionAssignmentMutator
- func NewJobMutator(etcdStore kv.TxnStore, logger *zap.SugaredLogger) common.JobMutator
- func NewMembershipMutator(etcdClient *kvstore.EtcdClient) common.MembershipMutator
- func NewNamespaceMutator(etcdStore kv.TxnStore) common.NamespaceMutator
- func NewSubscriberMutator(etcdClient *kvstore.EtcdClient) common.SubscriberMutator
- func NewTableSchemaMutator(store kv.TxnStore, logger *zap.SugaredLogger) common.TableSchemaMutator
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewEnumMutator ¶
func NewEnumMutator(store kv.TxnStore, schemaMutator common.TableSchemaMutator) common.EnumMutator
NewEnumMutator creates EnumMutator
func NewIngestionAssignmentMutator ¶
func NewIngestionAssignmentMutator(etcdStore kv.TxnStore) common.IngestionAssignmentMutator
NewIngestionAssignmentMutator creates new IngestionAssignmentMutator
func NewJobMutator ¶
func NewJobMutator(etcdStore kv.TxnStore, logger *zap.SugaredLogger) common.JobMutator
NewJobMutator creates new JobMutator
func NewMembershipMutator ¶
func NewMembershipMutator(etcdClient *kvstore.EtcdClient) common.MembershipMutator
NewMembershipMutator creates new MembershipMutator
func NewNamespaceMutator ¶
func NewNamespaceMutator(etcdStore kv.TxnStore) common.NamespaceMutator
NewNamespaceMutator returns a new NamespaceMutator
func NewSubscriberMutator ¶
func NewSubscriberMutator(etcdClient *kvstore.EtcdClient) common.SubscriberMutator
NewSubscriberMutator creates new subscriber mutator based on etcd
func NewTableSchemaMutator ¶
func NewTableSchemaMutator(store kv.TxnStore, logger *zap.SugaredLogger) common.TableSchemaMutator
NewTableSchemaMutator returns a new TableSchemaMutator
Types ¶
This section is empty.